#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_BITWISE_CAST_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_BITWISE_CAST_HPP_INCLUDED

#include <boost/simd/memory/include/functions/simd/bitwise_cast.hpp>

#endif
